<?php
class Connection extends PDO {

    private $stmt;
    public function __construct(string $dsn) {
        // $dsn = "pgsql:host=$this->host;port=$this->port;dbname=$this->database;user=$this->username;password=$this->password";
        // This should be remove or set to just use a debug 
        try {
            parent::__construct($dsn);
            echo "Successfully connected to the database";
            $this->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
            // should be a more accurate exception
        } catch (PDOException $e) {
            echo("Error connecting to the database: " . $e->getMessage());
            // do something ...
        }
    }
        

    /** * @param string $query
     * @param array $parameters *
     * @return bool Returns `true` on success, `false` otherwise
     */
    public function executeQuery(string $query, array $parameters = []) : bool{
        
        $this->stmt = parent::prepare($query);
        
        foreach ($parameters as $name => $value) {
            $this->stmt->bindValue($name, $value[0], $value[1]);
        }
        
        return $this->stmt->execute();
        
    }
    public function executeWithErrorHandling(string $query,array $params = []) {
        try {
            $this->beginTransaction();
            $this->executeQuery($query,$params);
            $this->commit();
            return $this->getResults();
        } catch (PDOException $e) {
            $this->rollBack();
            throw new Exception('Unexpected error on database client: ' . $e->getMessage());
        }
    }

    public function getResults() : array {
        return $this->stmt->fetchall(PDO::FETCH_ASSOC);
    }



}
?>